# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgCuriosities.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgCuriosities(object):
    def setupUi(self, wdgCuriosities):
        wdgCuriosities.setObjectName("wdgCuriosities")
        wdgCuriosities.resize(400, 299)
        self.layout_2 = QtWidgets.QHBoxLayout(wdgCuriosities)
        self.layout_2.setObjectName("layout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lblApp = QtWidgets.QLabel(wdgCuriosities)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lblApp.setFont(font)
        self.lblApp.setScaledContents(False)
        self.lblApp.setAlignment(QtCore.Qt.AlignCenter)
        self.lblApp.setIndent(-1)
        self.lblApp.setObjectName("lblApp")
        self.verticalLayout.addWidget(self.lblApp)
        self.scrollArea = QtWidgets.QScrollArea(wdgCuriosities)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 382, 241))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.layout = QtWidgets.QVBoxLayout()
        self.layout.setObjectName("layout")
        self.horizontalLayout_3.addLayout(self.layout)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout.addWidget(self.scrollArea)
        self.layout_2.addLayout(self.verticalLayout)

        self.retranslateUi(wdgCuriosities)
        QtCore.QMetaObject.connectSlotsByName(wdgCuriosities)

    def retranslateUi(self, wdgCuriosities):
        _translate = QtCore.QCoreApplication.translate
        self.lblApp.setText(_translate("wdgCuriosities", "Xulpymoney curiosities"))


import xulpymoney.images.xulpymoney_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgIndexRange.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgIndexRange(object):
    def setupUi(self, wdgIndexRange):
        wdgIndexRange.setObjectName("wdgIndexRange")
        wdgIndexRange.resize(747, 519)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(wdgIndexRange)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lbl = QtWidgets.QLabel(wdgIndexRange)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl.sizePolicy().hasHeightForWidth())
        self.lbl.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lbl.setFont(font)
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout_3.addWidget(self.lbl)
        self.groupBox = QtWidgets.QGroupBox(wdgIndexRange)
        self.groupBox.setObjectName("groupBox")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.groupBox)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.spin = QtWidgets.QDoubleSpinBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spin.sizePolicy().hasHeightForWidth())
        self.spin.setSizePolicy(sizePolicy)
        self.spin.setMinimumSize(QtCore.QSize(200, 0))
        self.spin.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spin.setDecimals(1)
        self.spin.setSingleStep(0.1)
        self.spin.setProperty("value", 2.0)
        self.spin.setObjectName("spin")
        self.horizontalLayout.addWidget(self.spin)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.txtInvertir = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtInvertir.sizePolicy().hasHeightForWidth())
        self.txtInvertir.setSizePolicy(sizePolicy)
        self.txtInvertir.setMinimumSize(QtCore.QSize(200, 0))
        self.txtInvertir.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtInvertir.setObjectName("txtInvertir")
        self.horizontalLayout_2.addWidget(self.txtInvertir)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.txtMinimo = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtMinimo.sizePolicy().hasHeightForWidth())
        self.txtMinimo.setSizePolicy(sizePolicy)
        self.txtMinimo.setMinimumSize(QtCore.QSize(200, 0))
        self.txtMinimo.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtMinimo.setObjectName("txtMinimo")
        self.horizontalLayout_3.addWidget(self.txtMinimo)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_5.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.cmd = QtWidgets.QPushButton(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmd.sizePolicy().hasHeightForWidth())
        self.cmd.setSizePolicy(sizePolicy)
        self.cmd.setObjectName("cmd")
        self.verticalLayout_2.addWidget(self.cmd)
        self.horizontalLayout_5.addLayout(self.verticalLayout_2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem1)
        self.horizontalLayout_7.addLayout(self.horizontalLayout_5)
        self.verticalLayout_3.addWidget(self.groupBox)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem2)
        self.cmbBenchmarkCurrent = QtWidgets.QComboBox(wdgIndexRange)
        self.cmbBenchmarkCurrent.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContentsOnFirstShow)
        self.cmbBenchmarkCurrent.setObjectName("cmbBenchmarkCurrent")
        self.horizontalLayout_4.addWidget(self.cmbBenchmarkCurrent)
        self.cmdIRAnalisis = QtWidgets.QToolButton(wdgIndexRange)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/books.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdIRAnalisis.setIcon(icon)
        self.cmdIRAnalisis.setObjectName("cmdIRAnalisis")
        self.horizontalLayout_4.addWidget(self.cmdIRAnalisis)
        self.cmdIRInsertar = QtWidgets.QToolButton(wdgIndexRange)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdIRInsertar.setIcon(icon1)
        self.cmdIRInsertar.setObjectName("cmdIRInsertar")
        self.horizontalLayout_4.addWidget(self.cmdIRInsertar)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem3)
        self.verticalLayout_3.addLayout(self.horizontalLayout_4)
        self.table = myQTableWidget(wdgIndexRange)
        self.table.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.table.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.table.setAlternatingRowColors(True)
        self.table.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.table.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.table.setObjectName("table")
        self.table.setColumnCount(2)
        self.table.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(1, item)
        self.table.verticalHeader().setVisible(False)
        self.verticalLayout_3.addWidget(self.table)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.lblTotal = QtWidgets.QLabel(wdgIndexRange)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTotal.sizePolicy().hasHeightForWidth())
        self.lblTotal.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setBold(True)
        font.setWeight(75)
        self.lblTotal.setFont(font)
        self.lblTotal.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTotal.setObjectName("lblTotal")
        self.horizontalLayout_6.addWidget(self.lblTotal)
        self.cmbShowOptions = QtWidgets.QComboBox(wdgIndexRange)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbShowOptions.sizePolicy().hasHeightForWidth())
        self.cmbShowOptions.setSizePolicy(sizePolicy)
        self.cmbShowOptions.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.cmbShowOptions.setObjectName("cmbShowOptions")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/eye.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmbShowOptions.addItem(icon2, "")
        self.cmbShowOptions.addItem("")
        self.cmbShowOptions.addItem("")
        self.cmbShowOptions.addItem("")
        self.cmbShowOptions.addItem("")
        self.horizontalLayout_6.addWidget(self.cmbShowOptions)
        self.verticalLayout_3.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_8.addLayout(self.verticalLayout_3)
        self.actionTop = QtWidgets.QAction(wdgIndexRange)
        self.actionTop.setObjectName("actionTop")
        self.actionMiddle = QtWidgets.QAction(wdgIndexRange)
        self.actionMiddle.setObjectName("actionMiddle")
        self.actionBottom = QtWidgets.QAction(wdgIndexRange)
        self.actionBottom.setObjectName("actionBottom")

        self.retranslateUi(wdgIndexRange)
        QtCore.QMetaObject.connectSlotsByName(wdgIndexRange)

    def retranslateUi(self, wdgIndexRange):
        _translate = QtCore.QCoreApplication.translate
        self.lbl.setText(_translate("wdgIndexRange", "Investments by index range"))
        self.groupBox.setTitle(_translate("wdgIndexRange", "Report data"))
        self.label_2.setText(_translate("wdgIndexRange", "Percentage between ranges"))
        self.spin.setSuffix(_translate("wdgIndexRange", " %"))
        self.label.setText(_translate("wdgIndexRange", "Money to invest"))
        self.txtInvertir.setText(_translate("wdgIndexRange", "4000"))
        self.label_4.setText(_translate("wdgIndexRange", "Index lowest limit"))
        self.txtMinimo.setText(_translate("wdgIndexRange", "1000"))
        self.cmd.setText(_translate("wdgIndexRange", "Update ranges"))
        self.cmdIRAnalisis.setToolTip(_translate("wdgIndexRange", "Show benchmark report"))
        self.cmdIRAnalisis.setText(_translate("wdgIndexRange", "..."))
        self.cmdIRInsertar.setToolTip(_translate("wdgIndexRange", "Add a price to the benchmark"))
        self.cmdIRInsertar.setText(_translate("wdgIndexRange", "..."))
        item = self.table.horizontalHeaderItem(0)
        item.setText(_translate("wdgIndexRange", "Range"))
        item = self.table.horizontalHeaderItem(1)
        item.setText(_translate("wdgIndexRange", "Investments"))
        self.cmbShowOptions.setItemText(0, _translate("wdgIndexRange", "Marked to show investment operations"))
        self.cmbShowOptions.setItemText(1, _translate("wdgIndexRange", "Show ETF, Shares and Warrants Investment operations"))
        self.cmbShowOptions.setItemText(2, _translate("wdgIndexRange", "Show bonds"))
        self.cmbShowOptions.setItemText(3, _translate("wdgIndexRange", "Show funds"))
        self.cmbShowOptions.setItemText(4, _translate("wdgIndexRange", "Show all investment operations"))
        self.actionTop.setText(_translate("wdgIndexRange", "Top"))
        self.actionMiddle.setText(_translate("wdgIndexRange", "Middle"))
        self.actionBottom.setText(_translate("wdgIndexRange", "Bottom"))


from xulpymoney.ui.myqlineedit import myQLineEdit
from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc



import datetime
from PyQt5.QtCore import Qt, pyqtSlot
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import QDialog,  QMessageBox, QVBoxLayout
from xulpymoney.ui.wdgTwoCurrencyLineEdit import wdgTwoCurrencyLineEdit
from xulpymoney.libxulpymoney import InvestmentOperation, Money,  qmessagebox
from xulpymoney.ui.frmQuotesIBM import frmQuotesIBM
from xulpymoney.ui.Ui_frmInvestmentOperationsAdd import Ui_frmInvestmentOperationsAdd
from decimal import Decimal

class frmInvestmentOperationsAdd(QDialog, Ui_frmInvestmentOperationsAdd):
    def __init__(self, mem, inversion, operinversion,   parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.mem=mem
        self.investment=inversion
        self.operinversion=operinversion

        if self.investment.hasSameAccountCurrency():
            self.wdg2CCurrencyConversion.hide()
            
        self.lblType.setFixedWidth(200)
        self.lblShares.setFixedWidth(200)

        self.wdgDT.show_microseconds(False)
        self.wdg2CComission.setLabel(self.tr("Comission"))
        self.wdg2CTaxes.setLabel(self.tr("Taxes"))
        self.wdg2CCurrencyConversion.setLabel(self.tr("Conversion factor"))
        self.wdg2CPrice.setLabel(self.tr("Price"))
        self.wdg2CGross.setLabel(self.tr("Gross"))
        self.wdg2CNet.setLabel(self.tr("Net"))

        self.wdg2CGross.setReadOnly(True)
        self.wdg2CNet.setReadOnly(True)

        if self.operinversion==None:
            factor=Money(self.mem, 0, self.investment.product.currency).conversionFactor(self.investment.account.currency, self.mem.localzone.now())
        else:
            factor=self.operinversion.currency_conversion
        self.wdg2CCurrencyConversion.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CCurrencyConversion.setFactorMode(True)
        self.wdg2CTaxes.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CPrice.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CComission.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CCurrencyConversion.factorChanged.connect(self.on_wdg2CCurrencyConversion_factorChanged)

        if self.operinversion==None:#nuevo movimiento
            self.type=1
            self.operinversion=InvestmentOperation(self.mem)
            self.operinversion.investment=self.investment
            self.lblTitulo.setText(self.tr("New operation of {}").format(self.investment.name))
            self.mem.tiposoperaciones.qcombobox_investments_operations(self.cmbTiposOperaciones)
            self.wdgDT.set(self.mem)
        else:#editar movimiento
            self.type=2
            self.lblTitulo.setText(self.tr("{} operation edition").format(self.investment.name))
            self.mem.tiposoperaciones.qcombobox_investments_operations(self.cmbTiposOperaciones, self.operinversion.tipooperacion)
            self.wdgDT.set(self.mem, self.operinversion.datetime, self.mem.localzone)
            self.wdg2CGross.setTextA(self.operinversion.net(type=1))
            self.wdg2CNet.setTextA(self.operinversion.gross(type=1))
            self.wdg2CTaxes.setTextA(self.operinversion.impuestos)
            self.wdg2CComission.setTextA(self.operinversion.comision)
            self.wdg2CPrice.setTextA(self.operinversion.valor_accion)
            self.txtAcciones.setText(self.operinversion.shares)

        self.wdg2CTaxes.textChanged.connect(self.on_wdg2CTaxes_mytextChanged)
        self.wdg2CComission.textChanged.connect(self.on_wdg2CComission_mytextChanged)
        self.wdg2CPrice.textChanged.connect(self.on_wdg2CPrice_mytextChanged)

    def on_wdg2CCurrencyConversion_factorChanged(self, factor):
        self.wdg2CComission.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CPrice.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CTaxes.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CGross.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)
        self.wdg2CNet.set(self.mem, self.investment.product.currency, self.investment.account.currency,  factor)

    def on_cmdComissionCalculator_released(self):
        d=QDialog(self)     
        d.resize(800, 80)
        d.setWindowTitle(self.tr("Comission calculator"))
        d.setWindowIcon(QIcon(":/xulpymoney/tools-wizard.png"))
        t=wdgTwoCurrencyLineEdit(d)
        t.label.setWordWrap(True)
        t.set(self.mem, self.investment.product.currency, self.investment.account.currency, self.wdg2CCurrencyConversion.factor)
        t.setLabel(self.tr("Please add the final amount annoted in your bank account, then close this window"))
        lay = QVBoxLayout(d)
        lay.addWidget(t)
        d.exec_()
        self.wdg2CComission.setTextA(t.decimalA()-self.wdg2CPrice.decimalA()*self.txtAcciones.decimal())

    def on_cmd_released(self):        
        if self.wdg2CComission.isValid() and self.wdg2CCurrencyConversion.isValid() and self.wdg2CPrice.isValid() and self.wdg2CTaxes.isValid()==False:
            qmessagebox(self.tr("Some fields are wrong"))
            return

        id_tiposoperaciones=int(self.cmbTiposOperaciones.itemData(self.cmbTiposOperaciones.currentIndex()))
        self.operinversion.tipooperacion=self.mem.tiposoperaciones.find_by_id(id_tiposoperaciones)
        self.operinversion.impuestos=self.wdg2CTaxes.decimalA()
        self.operinversion.comision=self.wdg2CComission.decimalA()
        self.operinversion.valor_accion=self.wdg2CPrice.decimalA()
        self.operinversion.currency_conversion=self.wdg2CCurrencyConversion.factor
        self.operinversion.shares=self.txtAcciones.decimal()
        if id_tiposoperaciones==5: #Venta
#            self.operinversion.importe=self.txtNetBruto.decimal()
            self.operinversion.show_in_ranges=False
            if self.operinversion.shares>Decimal('0'):
                m=QMessageBox()
                m.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
                m.setIcon(QMessageBox.Information)
                m.setText(self.tr("Sale Shares number must be negative"))
                m.exec_()    
                return        
        elif id_tiposoperaciones==4: #Compra
#            self.operinversion.importe=self.txtNet.decimal()
            if self.operinversion.shares<0: 
                m=QMessageBox()
                m.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
                m.setIcon(QMessageBox.Information)
                m.setText(self.tr("Purchase shares number must be positive"))
                m.exec_()    
                return
        elif id_tiposoperaciones==6: #Añadido    
#            self.operinversion.importe=self.txtNet.decimal()
            if self.operinversion.shares<0: 
                m=QMessageBox()
                m.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
                m.setIcon(QMessageBox.Information)
                m.setText(self.tr("Added shares number must be positive"))
                m.exec_()    
                return            
#        elif id_tiposoperaciones==8: #Traspaso fondos
#            self.operinversion.importe=self.txtNet.decimal()
        
        if self.operinversion.impuestos<Decimal('0') or  self.operinversion.comision<Decimal('0') or self.operinversion.valor_accion<Decimal('0'):            
            m=QMessageBox()
            m.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
            m.setIcon(QMessageBox.Information)
            m.setText(self.tr("Share price, taxes and comission must be positive amounts"))
            m.exec_()    
            return
            
        self.operinversion.datetime=self.wdgDT.datetime()
        self.operinversion.save()    
        self.mem.con.commit()#Guarda todos los cambios en bd.
        
        ##Mete indice referencia.
        if self.type==1  and id_tiposoperaciones==4:#Añadir y compra
            w=frmQuotesIBM(self.mem, self.mem.data.benchmark, None, self)
            #Quita un minuto para que enganche con operación
            w.wdgDT.set(self.mem, self.wdgDT.datetime()-datetime.timedelta(seconds=1), self.mem.localzone)
            w.chkCanBePurged.setCheckState(Qt.Unchecked)
            w.txtQuote.setFocus()
            w.exec_() 
            self.mem.data.benchmark.result.basic.load_from_db()                
        self.done(0)

    def on_cmbTiposOperaciones_currentIndexChanged(self, index):
        id_tiposoperaciones=int(self.cmbTiposOperaciones.itemData(self.cmbTiposOperaciones.currentIndex()))
        if id_tiposoperaciones==6:#Añadido acciones
            self.wdg2CPrice.setTextA(0)
            self.wdg2CPrice.setEnabled(False)
        else:
            self.wdg2CPrice.setEnabled(True)
        self.on_txtAcciones_textChanged()

    def on_txtAcciones_textChanged(self):
        """El importe a grabar en BD cuando es una compra es el importe neto, cuando es una venta es el importe bruto"""
        if self.txtAcciones.isValid() and self.wdg2CPrice.isValid():
            self.cmdComissionCalculator.setEnabled(True)
        else:
            self.cmdComissionCalculator.setEnabled(False)
        id_tiposoperaciones=int(self.cmbTiposOperaciones.itemData(self.cmbTiposOperaciones.currentIndex()))
        try:
            if id_tiposoperaciones==4:#Compra
                importe=abs(round(self.txtAcciones.decimal()*self.wdg2CPrice.decimalA(), 2))
                self.wdg2CGross.setTextA(importe)
                self.wdg2CNet.setTextA(importe+self.wdg2CComission.decimalA()+self.wdg2CTaxes.decimalA())
            if id_tiposoperaciones==5:#Venta
                importe=abs(round(self.txtAcciones.decimal()*self.wdg2CPrice.decimalA(), 2))
                self.wdg2CGross.setTextA(importe)
                self.wdg2CNet.setTextA(importe-self.wdg2CComission.decimalA()-self.wdg2CTaxes.decimalA())
            if id_tiposoperaciones==8:#Traspaso
                importe=abs(round(self.txtAcciones.decimal()*self.wdg2CPrice.decimalA(), 2))
                self.wdg2CGross.setTextA(importe)
                self.wdg2CNet.setTextA(importe+self.wdg2CComission.decimalA()+self.wdg2CTaxes.decimalA())
        except:
            pass

    @pyqtSlot()
    def on_wdg2CPrice_mytextChanged(self):
        self.on_txtAcciones_textChanged()

    @pyqtSlot()
    def on_wdg2CComission_mytextChanged(self):
        self.on_txtAcciones_textChanged()

    @pyqtSlot()
    def on_wdg2CTaxes_mytextChanged(self):
        self.on_txtAcciones_textChanged()





import datetime
from PyQt5.QtCore import Qt
from PyQt5.QtWidgets import QWidget, QDialog, QVBoxLayout
from xulpymoney.ui.myqtablewidget import myQTableWidget
from xulpymoney.ui.Ui_wdgProductsComparation import Ui_wdgProductsComparation
from PyQt5.QtChart import QValueAxis
from xulpymoney.libxulpymoney import ProductComparation
from xulpymoney.libxulpymoneyfunctions import qmessagebox,  day_end_from_date
from xulpymoney.ui.canvaschart import  VCTemporalSeries

class wdgProductsComparation(QWidget, Ui_wdgProductsComparation):
    def __init__(self, mem,  product1=None,  product2=None, parent = None, name = None):
        QWidget.__init__(self,  parent)
        self.setupUi(self)
        self.mem=mem
        self.parent=parent

        self.selector1.setupUi(self.mem)
        self.selector1.label.setText(self.tr("Select a product to compare"))
        self.selector1.setSelected(product1)

        self.selector1.showProductButton(False)
        self.selector2.setupUi(self.mem)
        self.selector2.label.setText(self.tr("Select a product to compare"))
        if product2==None:
            self.selector2.setSelected(self.mem.data.benchmark)
        else:
            self.selector2.setSelected(product2)

        self.selector2.showProductButton(False)
        self.cmbCompareTypes.setCurrentIndex(0)
        self.comparation=None

    def on_cmdComparation_released(self):
        inicio=datetime.datetime.now()
        if self.selector1.selected==None or self.selector2.selected==None:
            qmessagebox(self.tr("You must select a product to compare with"))
            return
        self.comparation=ProductComparation(self.mem, self.selector1.selected, self.selector2.selected)
        if self.viewCompare!=None:
            self.viewCompare.hide()
            self.verticalLayout.removeWidget(self.viewCompare)
        if self.comparation.canBeMade()==False:
            qmessagebox(self.tr("Comparation can't be made."))
            return

        self.deCompare.setMinimumDate(self.comparation.dates()[0])
        self.deCompare.setMaximumDate(self.comparation.dates()[len(self.comparation.dates())-1-1])#Es menos 2, ya que hay alguna funcion de comparation que lo necesita
        self.comparation.setFromDate(self.deCompare.date())

        self.viewCompare=VCTemporalSeries()
        if self.cmbCompareTypes.currentIndex()==0:#Not changed data

            ls1=self.viewCompare.appendTemporalSeries(self.comparation.product1.name.upper(), self.comparation.product1.currency)#Line seies
            ls2=self.viewCompare.appendTemporalSeries(self.comparation.product2.name.upper(), self.comparation.product1.currency)#Line seies
            dates=self.comparation.dates()
            closes1=self.comparation.product1Closes()
            closes2=self.comparation.product2Closes()
            for i,  date in enumerate(dates):
                self.viewCompare.appendTemporalSeriesData(ls1, day_end_from_date(date, self.mem.localzone) , closes1[i])
                self.viewCompare.appendTemporalSeriesData(ls2, day_end_from_date(date, self.mem.localzone) , closes2[i])
            
            # BEGIN DISPLAY)
            self.viewCompare.setChart(self.viewCompare.chart)
            self.viewCompare.setAxisFormat(self.viewCompare.axisX, self.viewCompare.minx, self.viewCompare.maxx, 1)
            self.viewCompare.setAxisFormat(self.viewCompare.axisY, min(self.comparation.product1Closes()), max(self.comparation.product1Closes()),  0)
            axis3=QValueAxis()
            self.viewCompare.chart.addAxis(self.viewCompare.axisY, Qt.AlignLeft);
            self.viewCompare.chart.addAxis(self.viewCompare.axisX, Qt.AlignBottom);
            self.viewCompare.chart.addAxis(axis3, Qt.AlignRight)

            self.viewCompare.chart.addSeries(ls1)
            ls1.attachAxis(self.viewCompare.axisX)
            ls1.attachAxis(self.viewCompare.axisY)
            self.viewCompare.axisY.setRange(min(self.comparation.product1Closes()), max(self.comparation.product1Closes()))

            self.viewCompare.chart.addSeries(ls2)
            ls2.attachAxis(self.viewCompare.axisX)
            ls2.attachAxis(axis3)
            axis3.setRange (min(self.comparation.product2Closes()), max(self.comparation.product2Closes()))

            if self.viewCompare._allowHideSeries==True:
                for marker in self.viewCompare.chart.legend().markers():
                    try:
                        marker.clicked.disconnect()
                    except:
                        pass
                    marker.clicked.connect(self.viewCompare.on_marker_clicked)

            self.viewCompare.repaint()
            ###END DISPLAY

        elif self.cmbCompareTypes.currentIndex()==1:#Scatter
            pass

        elif self.cmbCompareTypes.currentIndex()==2:#Controlling percentage evolution.

            ls1=self.viewCompare.appendTemporalSeries(self.comparation.product1.name.upper(), self.comparation.product1.currency)#Line seies
            ls2=self.viewCompare.appendTemporalSeries(self.comparation.product2.name.upper(), self.comparation.product1.currency)#Line seies
            dates=self.comparation.dates()
            closes1=self.comparation.product1PercentageFromFirstProduct2Price()
            closes2=self.comparation.product2Closes()
            for i,  date in enumerate(dates):
                self.viewCompare.appendTemporalSeriesData(ls1, day_end_from_date(date, self.mem.localzone) , closes1[i])
                self.viewCompare.appendTemporalSeriesData(ls2, day_end_from_date(date, self.mem.localzone) , closes2[i])
            self.viewCompare.display()
        elif self.cmbCompareTypes.currentIndex()==3:#Controlling percentage evolution reducing leverage.
            ls1=self.viewCompare.appendTemporalSeries(self.comparation.product1.name.upper(), self.comparation.product1.currency)#Line seies
            ls2=self.viewCompare.appendTemporalSeries(self.comparation.product2.name.upper(), self.comparation.product1.currency)#Line seies
            dates=self.comparation.dates()
            closes1=self.comparation.product1PercentageFromFirstProduct2PriceLeveragedReduced()
            closes2=self.comparation.product2Closes()
            for i,  date in enumerate(dates):
                self.viewCompare.appendTemporalSeriesData(ls1, day_end_from_date(date, self.mem.localzone) , closes1[i])
                self.viewCompare.appendTemporalSeriesData(ls2, day_end_from_date(date, self.mem.localzone) , closes2[i])
            self.viewCompare.display()
        elif self.cmbCompareTypes.currentIndex()==4:#Controlling inverse percentage evolution.
            ls1=self.viewCompare.appendTemporalSeries(self.comparation.product1.name.upper(), self.comparation.product1.currency)#Line seies
            ls2=self.viewCompare.appendTemporalSeries(self.comparation.product2.name.upper(), self.comparation.product1.currency)#Line seies
            dates=self.comparation.dates()
            closes1=self.comparation.product1PercentageFromFirstProduct2InversePrice()
            closes2=self.comparation.product2Closes()
            for i,  date in enumerate(dates):
                self.viewCompare.appendTemporalSeriesData(ls1, day_end_from_date(date, self.mem.localzone) , closes1[i])
                self.viewCompare.appendTemporalSeriesData(ls2, day_end_from_date(date, self.mem.localzone) , closes2[i])
            self.viewCompare.display()
        elif self.cmbCompareTypes.currentIndex()==5:#Controlling inverse percentage evolution reducing leverage.
            ls1=self.viewCompare.appendTemporalSeries(self.comparation.product1.name.upper(), self.comparation.product1.currency)#Line seies
            ls2=self.viewCompare.appendTemporalSeries(self.comparation.product2.name.upper(), self.comparation.product1.currency)#Line seies
            dates=self.comparation.dates()
            closes1=self.comparation.product1PercentageFromFirstProduct2InversePriceLeveragedReduced()
            closes2=self.comparation.product2Closes()
            for i,  date in enumerate(dates):
                self.viewCompare.appendTemporalSeriesData(ls1, day_end_from_date(date, self.mem.localzone) , closes1[i])
                self.viewCompare.appendTemporalSeriesData(ls2, day_end_from_date(date, self.mem.localzone) , closes2[i])
            self.viewCompare.display()


        self.verticalLayout.addWidget(self.viewCompare)
        print ("Comparation took {}".format(datetime.datetime.now()-inicio))

    def on_cmdComparationData_released(self):
        if self.comparation==None:
            qmessagebox(self.tr("You need to compare products first"))
            return
        d=QDialog(self)
        d.resize(800, 600)
        d.setWindowTitle(self.tr("Comparation data table"))
        table=myQTableWidget(d)
        table.settings(self.mem,"frmProductReport" , "tblCompartionData")
        self.comparation.myqtablewidget(table)
        lay = QVBoxLayout(d)
        lay.addWidget(table)
        d.show()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmSellingPoint.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmSellingPoint(object):
    def setupUi(self, frmSellingPoint):
        frmSellingPoint.setObjectName("frmSellingPoint")
        frmSellingPoint.setWindowModality(QtCore.Qt.WindowModal)
        frmSellingPoint.resize(790, 596)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/tools-wizard.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmSellingPoint.setWindowIcon(icon)
        frmSellingPoint.setSizeGripEnabled(True)
        frmSellingPoint.setModal(True)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(frmSellingPoint)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lblTitulo = QtWidgets.QLabel(frmSellingPoint)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lblTitulo.setFont(font)
        self.lblTitulo.setStyleSheet("color: rgb(0, 128, 0);")
        self.lblTitulo.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitulo.setObjectName("lblTitulo")
        self.verticalLayout_3.addWidget(self.lblTitulo)
        self.groupBox = QtWidgets.QGroupBox(frmSellingPoint)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.radTPC = QtWidgets.QRadioButton(self.groupBox)
        self.radTPC.setChecked(True)
        self.radTPC.setObjectName("radTPC")
        self.horizontalLayout_2.addWidget(self.radTPC)
        self.spnGainsPercentage = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.spnGainsPercentage.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnGainsPercentage.setProperty("showGroupSeparator", False)
        self.spnGainsPercentage.setMaximum(1000.0)
        self.spnGainsPercentage.setSingleStep(0.5)
        self.spnGainsPercentage.setProperty("value", 10.0)
        self.spnGainsPercentage.setObjectName("spnGainsPercentage")
        self.horizontalLayout_2.addWidget(self.spnGainsPercentage)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.radGain = QtWidgets.QRadioButton(self.groupBox)
        self.radGain.setObjectName("radGain")
        self.horizontalLayout.addWidget(self.radGain)
        self.txtGanancia = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtGanancia.sizePolicy().hasHeightForWidth())
        self.txtGanancia.setSizePolicy(sizePolicy)
        self.txtGanancia.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtGanancia.setObjectName("txtGanancia")
        self.horizontalLayout.addWidget(self.txtGanancia)
        self.lblAmountSymbol = QtWidgets.QLabel(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblAmountSymbol.sizePolicy().hasHeightForWidth())
        self.lblAmountSymbol.setSizePolicy(sizePolicy)
        self.lblAmountSymbol.setText("")
        self.lblAmountSymbol.setObjectName("lblAmountSymbol")
        self.horizontalLayout.addWidget(self.lblAmountSymbol)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.radPrice = QtWidgets.QRadioButton(self.groupBox)
        self.radPrice.setObjectName("radPrice")
        self.horizontalLayout_8.addWidget(self.radPrice)
        self.txtPrice = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtPrice.sizePolicy().hasHeightForWidth())
        self.txtPrice.setSizePolicy(sizePolicy)
        self.txtPrice.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtPrice.setObjectName("txtPrice")
        self.horizontalLayout_8.addWidget(self.txtPrice)
        self.lblPriceSymbol = QtWidgets.QLabel(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblPriceSymbol.sizePolicy().hasHeightForWidth())
        self.lblPriceSymbol.setSizePolicy(sizePolicy)
        self.lblPriceSymbol.setText("")
        self.lblPriceSymbol.setObjectName("lblPriceSymbol")
        self.horizontalLayout_8.addWidget(self.lblPriceSymbol)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.verticalLayout_3.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(frmSellingPoint)
        self.groupBox_2.setObjectName("groupBox_2")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.chkGainsTime = QtWidgets.QCheckBox(self.groupBox_2)
        self.chkGainsTime.setObjectName("chkGainsTime")
        self.verticalLayout_2.addWidget(self.chkGainsTime)
        self.chkPonderanAll = QtWidgets.QCheckBox(self.groupBox_2)
        self.chkPonderanAll.setObjectName("chkPonderanAll")
        self.verticalLayout_2.addWidget(self.chkPonderanAll)
        self.horizontalLayout_3.addLayout(self.verticalLayout_2)
        self.verticalLayout_3.addWidget(self.groupBox_2)
        self.tab = QtWidgets.QTabWidget(frmSellingPoint)
        self.tab.setObjectName("tab")
        self.tab_current = QtWidgets.QWidget()
        self.tab_current.setObjectName("tab_current")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.tab_current)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.table = myQTableWidget(self.tab_current)
        self.table.setObjectName("table")
        self.table.setColumnCount(7)
        self.table.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(6, item)
        self.table.verticalHeader().setVisible(False)
        self.horizontalLayout_5.addWidget(self.table)
        self.tab.addTab(self.tab_current, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.tableSP = myQTableWidget(self.tab_2)
        self.tableSP.setObjectName("tableSP")
        self.tableSP.setColumnCount(7)
        self.tableSP.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableSP.setHorizontalHeaderItem(6, item)
        self.tableSP.verticalHeader().setVisible(False)
        self.horizontalLayout_6.addWidget(self.tableSP)
        self.tab.addTab(self.tab_2, "")
        self.verticalLayout_3.addWidget(self.tab)
        self.cmd = QtWidgets.QPushButton(frmSellingPoint)
        self.cmd.setObjectName("cmd")
        self.verticalLayout_3.addWidget(self.cmd)
        self.horizontalLayout_7.addLayout(self.verticalLayout_3)

        self.retranslateUi(frmSellingPoint)
        self.tab.setCurrentIndex(0)
        self.txtGanancia.textEdited['QString'].connect(self.radGain.toggle)
        QtCore.QMetaObject.connectSlotsByName(frmSellingPoint)

    def retranslateUi(self, frmSellingPoint):
        _translate = QtCore.QCoreApplication.translate
        frmSellingPoint.setWindowTitle(_translate("frmSellingPoint", "Selling point calculation"))
        self.lblTitulo.setText(_translate("frmSellingPoint", "Selling point calculation"))
        self.groupBox.setTitle(_translate("frmSellingPoint", "Select your gain"))
        self.radTPC.setText(_translate("frmSellingPoint", "Select a &gain percentage from invested in account currency"))
        self.spnGainsPercentage.setSuffix(_translate("frmSellingPoint", " %"))
        self.radGain.setText(_translate("frmSellingPoint", "Se&lect a gain amount in the account currency"))
        self.txtGanancia.setToolTip(_translate("frmSellingPoint", "Select a gain amount"))
        self.txtGanancia.setText(_translate("frmSellingPoint", "1000"))
        self.radPrice.setText(_translate("frmSellingPoint", "Selec&t a price in product currency"))
        self.txtPrice.setText(_translate("frmSellingPoint", "10"))
        self.groupBox_2.setTitle(_translate("frmSellingPoint", "Selling point calculation options"))
        self.chkGainsTime.setText(_translate("frmSellingPoint", "Remove operations less than a year"))
        self.chkPonderanAll.setText(_translate("frmSellingPoint", "Include shares of the same product from different investments"))
        item = self.table.horizontalHeaderItem(0)
        item.setText(_translate("frmSellingPoint", "Date"))
        item = self.table.horizontalHeaderItem(1)
        item.setText(_translate("frmSellingPoint", "Investment (Bank)"))
        item = self.table.horizontalHeaderItem(2)
        item.setText(_translate("frmSellingPoint", "Operation type"))
        item = self.table.horizontalHeaderItem(3)
        item.setText(_translate("frmSellingPoint", "Shares"))
        item = self.table.horizontalHeaderItem(4)
        item.setText(_translate("frmSellingPoint", "Bought price"))
        item = self.table.horizontalHeaderItem(5)
        item.setText(_translate("frmSellingPoint", "Invested"))
        item = self.table.horizontalHeaderItem(6)
        item.setText(_translate("frmSellingPoint", "Pending"))
        self.tab.setTabText(self.tab.indexOf(self.tab_current), _translate("frmSellingPoint", "Current state"))
        item = self.tableSP.horizontalHeaderItem(0)
        item.setText(_translate("frmSellingPoint", "Date"))
        item = self.tableSP.horizontalHeaderItem(1)
        item.setText(_translate("frmSellingPoint", "Investment (Bank)"))
        item = self.tableSP.horizontalHeaderItem(2)
        item.setText(_translate("frmSellingPoint", "Operation type"))
        item = self.tableSP.horizontalHeaderItem(3)
        item.setText(_translate("frmSellingPoint", "Shares"))
        item = self.tableSP.horizontalHeaderItem(4)
        item.setText(_translate("frmSellingPoint", "Price"))
        item = self.tableSP.horizontalHeaderItem(5)
        item.setText(_translate("frmSellingPoint", "Invested"))
        item = self.tableSP.horizontalHeaderItem(6)
        item.setText(_translate("frmSellingPoint", "Pending"))
        self.tab.setTabText(self.tab.indexOf(self.tab_2), _translate("frmSellingPoint", "Selling point state"))
        self.cmd.setText(_translate("frmSellingPoint", "Set the selling point"))


from xulpymoney.ui.myqlineedit import myQLineEdit
from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc
